@@ -59,13 +59,6 @@ TrainingSelectionView::TrainingSelectionView(QWidget* parent) : QWidget(parent)
 
     m_checkbox = new QCheckBox("Portrait", this);
 
-
-//    QDialogButtonBox *buttons = new QDialogButtonBox(this);
-//    buttons->setOrientation(Qt::Horizontal);
-//    buttons->addButton(tr("Start"),QDialogButtonBox::AcceptRole);
-//
-//    connect(buttons, SIGNAL(accepted()),this,SLOT(start()));
-
     QPushButton *m_button = new QPushButton();
     m_button->setText(tr("Start"));
 
@@ -102,6 +95,7 @@ void TrainingSelectionView::slotInitView()
         QString dictionaryName = settings->dictionaries().first();
         settings->openDictionary(dictionaryName);
     }
+    slotDictionaryChanged();
 }
 
 void TrainingSelectionView::start()
@@ -109,7 +103,7 @@ void TrainingSelectionView::start()
     // check what is selected
     if(m_ComboDictionary && m_ComboDictionary->count()) {
         slotDictionarySelected(m_ComboDictionary->currentIndex());
-        QueryMee* trainer = new QueryMee();
+        QueryMee* trainer = new QueryMee(this);
         trainer->setLession(m_ComboLesson->currentIndex());
         trainer->setQuestionLanguage(m_ComboQuestionLang->currentIndex());
         trainer->setAnswerLanguage(m_ComboAnswerLang->currentIndex());
@@ -117,7 +111,10 @@ void TrainingSelectionView::start()
        if(m_checkbox->isChecked() == true){
             trainer->setAttribute(Qt::WA_Maemo5PortraitOrientation, true);
         }
+
+        trainer->setAttribute(Qt::WA_Maemo5StackedWindow);
 #endif
+        trainer->setWindowFlags(trainer->windowFlags() | Qt::Window);
         trainer->startTraining();
     } else {
         QueryMeeSettings::instance()->openDictionary();
